; VBXE summary
;
; $D640   video control bit0 - xdl enable
;                       bit1 - enable 256 colors for GTIA instead of 128
;                       bit2 - disable transparency for color 0
;                       bit3 - enable color $xF being transparent
; $D641-3 XDL address low/mid/high
; $D644   MSEL write $Cx to update palette x (after MB0), write $80 to
; $D645   MB0 write colr index (after RGB) \               update 
; $D646   MB1 write R component             \             priority
; $D647   MB2 write G component              \             definitions
; $D648   MB3 write B component               \
; $D649   colmask - mask applied to overlay color for collision detection
; $D64A   colclr - resets coldetect
;       read = coldetect - bits correspond to GTIA colors that have collided
;                          with an overlay color
; $D64C   ma-cpu   \ bit 7 enables VRAM window at $2000-$3FFF
; $D64D   ma-antic / bits 0-5 select bank
; $D64E   mb-cpu   \ bit 7 enables VRAM window at $4000-$7FFF
; $D64F   mb-antic / bits 0-4 select bank
; $D650-2 blitter address
;       read $D650 = collision code >0 pixel value that was overwritten
; $D653   blitter start - write 1 to start, write 0 to stop
;       read = blitter busy (busy when non-zero)
; $D654   IRQ control - bit 0 enables blitter done IRQ
;
; XDL 
; byte 0
;   bit 0 - set to enable text mode
;   bit 1 - set to enable gfx mode
;   bit 2 - set to disable overlay
;   bit 3 - set to enable color attributes
;   bit 4 - set to disable color attributes
;   bit 5 - RPTL
;   bit 6 - OVADR
;   bit 7 - OVSCRL
; byte 1
;   bit 0 - CHBASE
;   bit 1 - MAPADR (color attributes)
;   bit 2 - MAPPAR (color attributes)
;   bit 3 - OVATT
;   bit 4 - enable hi-res mode (640)
;   bit 5 - enable low-res mode (160)
;   bit 6 - reserved
;   bit 7 - end of XDL, wait for VBLANK

; RPTL - number of scanlines-1 for this modeline
; OVADR - 3 bytes overlay address, 2 bytes line step size
; OVSCRL - 1 byte hscroll, 1 byte vscroll
; CHBASE - high byte of charset address
; MAPADR - 3 bytes map address, 2 bytes line step size
; MAPPAR - 1b hscroll, 1b vscroll, 1b cell width-1, 1b cell height-1
; OVATT - byte 1 - overlay width and color shift
;         byte 2 - priority bits - bit0 - overlay above PM0
;                                  bit1 - ... PM1
;                                  bit2 - ... PM2
;                                  bit3 - ... PM3
;                                  bit4 - ... PF0
;                                  bit5 - ... PF1
;                                  bit6 - ... PF2
;                                  bit7 - ... PF3
; attributes map format
; byte 0 - colpf0 substitute color
; byte 1 - colpf1
; byte 2 - colpf2
; byte 3 - bits 0-1 - priority setting select
;          bit 2 - resolution override
;          bit 3 - reserved
;          bits 4-5 - overlay palette select
;          bits 6-7 - GTIA palette select
;
; Blitter Command Block
; bytes 0-2 source addr
; bytes 3-4 source line step
; bytes 5-7 dest. addr
; bytes 8-9 dest. line step
; bytes 10-11 obj width-1 in bytes
; byte 12 obj height
; byte 13 source AND mask
; byte 14 source XOR mask
; byte 15 collision AND mask
; byte 16 zoom bits 0-2 - x zoom
;              bit 3 - increment by 2 if set, else increment by 1
;              bits 4-6 - y zoom
; byte 17 pattern - bit 7 enables repeating source data horizontally
;                   bits 0-5 pattern width       
; byte 18 control - bits 0-2 - MODE
;                   bit3 - NEXT - 0 for last BCB
;                   bit4 - source x decrement if set, else increment
;                   bit5 - source y
;                   bit6 - dest. x
;                   bit7 - dest. y
; mode 0 - copy opaque
; mode 1 - copy with transparency
; mode 2 - source added to dest.
; mode 3 - OR
; mode 4 - AND
; mode 5 - XOR
; mode 6 - same as 1, with transparency and collision detection by nibbles
; mode 7 - reserved

VBXE_BASE		equ	0xd600		;d600, d700 or 0 (autodetection)
VBXE_VIDEO_CONTROL	equ	VBXE_BASE+0x40
VBXE_XDL_ADR0		equ	VBXE_BASE+0x41
VBXE_XDL_ADR1		equ	VBXE_BASE+0x42
VBXE_XDL_ADR2		equ	VBXE_BASE+0x43
VBXE_CSEL		equ	VBXE_BASE+0x44
VBXE_PSEL		equ	VBXE_BASE+0x45
VBXE_CR			equ	VBXE_BASE+0x46
VBXE_CG			equ	VBXE_BASE+0x47
VBXE_CB			equ	VBXE_BASE+0x48
VBXE_COLMASK		equ	VBXE_BASE+0x49
VBXE_COLCLR		equ	VBXE_BASE+0x4a
VBXE_MA_CPU		equ	VBXE_BASE+0x4c
VBXE_MA_ANTIC		equ	VBXE_BASE+0x4d
VBXE_MB_CPU		equ	VBXE_BASE+0x4e
VBXE_MB_ANTIC		equ	VBXE_BASE+0x4f
VBXE_BL_ADR0		equ	VBXE_BASE+0x50
VBXE_BL_ADR1		equ	VBXE_BASE+0x51
VBXE_BL_ADR2		equ	VBXE_BASE+0x52
VBXE_BLITTER_START	equ	VBXE_BASE+0x53
VBXE_BLITTER_BUSY	equ	VBXE_BASE+0x53
VBXE_IRQ_CONTROL	equ	VBXE_BASE+0x54
VBXE_MEMAC_B_CONTROL	equ	VBXE_BASE+0x5d